pub struct SourceNormalizerPacketCapabilities {
pub supported_runtime_profiles: Vec<String>,
pub max_level: SourceNormalizerNormalizeLevel,
pub media_kinds: Vec<SourceNormalizerPacketMediaKind>,
pub codecs: Vec<String>,
pub bitstream_formats: Vec<DecoderBitstreamFormat>,
pub supports_seek: bool,
pub supports_flush: bool,
pub required_capabilities: SourceNormalizerRequiredCapabilities,
pub max_sessions: Option<u32>,
}Expand description
Capabilities advertised by a packet-stream source normalizer plugin.
Fields
supported_runtime_profiles: Vec<String>max_level: SourceNormalizerNormalizeLevelmedia_kinds: Vec<SourceNormalizerPacketMediaKind>codecs: Vec<String>bitstream_formats: Vec<DecoderBitstreamFormat>supports_seek: boolsupports_flush: boolrequired_capabilities: SourceNormalizerRequiredCapabilitiesmax_sessions: Option<u32>Implementations
Sourceimpl SourceNormalizerPacketCapabilities
impl SourceNormalizerPacketCapabilities
Sourcepub fn supports_runtime_profile(&self, runtime_profile: &str) -> bool
pub fn supports_runtime_profile(&self, runtime_profile: &str) -> bool
Returns whether this plugin advertises a runtime profile.
Sourcepub fn supports_codec(&self, codec: &str) -> bool
pub fn supports_codec(&self, codec: &str) -> bool
Returns whether this plugin advertises a codec.
Sourcepub fn supports_media_kind(
&self,
media_kind: SourceNormalizerPacketMediaKind,
) -> bool
pub fn supports_media_kind( &self, media_kind: SourceNormalizerPacketMediaKind, ) -> bool
Returns whether this plugin advertises packet output for a media kind.
Sourcepub fn supports_bitstream_format(&self, format: &DecoderBitstreamFormat) -> bool
pub fn supports_bitstream_format(&self, format: &DecoderBitstreamFormat) -> bool
Returns whether this plugin advertises a packet bitstream format.