DecoderCapabilities

Struct DecoderCapabilities 

pub struct DecoderCapabilities {
    pub codecs: Vec<DecoderCodecCapability>,
    pub supports_hardware_decode: bool,
    pub supports_cpu_video_frames: bool,
    pub supports_audio_frames: bool,
    pub supports_pcm_frames: bool,
    pub supports_gpu_handles: bool,
    pub supports_presentation_release: bool,
    pub supports_flush: bool,
    pub supports_drain: bool,
    pub max_sessions: Option<u32>,
}
Decoder plugin capability payload returned through the dynamic ABI.

Fields

codecs: Vec<DecoderCodecCapability>supports_hardware_decode: boolsupports_cpu_video_frames: boolsupports_audio_frames: bool

Supports decoded audio frames in plugin-managed audio sessions.

supports_pcm_frames: bool

Supports decoded PCM frame output through receive_pcm_frame.

supports_gpu_handles: boolsupports_presentation_release: bool

Supports release calls that distinguish presented frames from discarded frames.

supports_flush: boolsupports_drain: boolmax_sessions: Option<u32>

Implementations

Source

impl DecoderCapabilities

pub fn supports_codec(&self, codec: &str, media_kind: DecoderMediaKind) -> bool

Returns whether this plugin advertises support for a codec/media pair.