DecoderSessionConfig

Struct DecoderSessionConfig 

pub struct DecoderSessionConfig {
Show 24 fields pub codec: String, pub media_kind: DecoderMediaKind, pub extradata: Vec<u8>, pub bitstream_format: Option<DecoderBitstreamFormat>, pub width: Option<u32>, pub height: Option<u32>, pub coded_width: Option<u32>, pub coded_height: Option<u32>, pub reorder_depth: Option<u32>, pub sample_rate: Option<u32>, pub channels: Option<u16>, pub channel_layout: Option<String>, pub target_pcm_format: Option<DecoderFrameFormat>, pub target_pcm_sample_layout: Option<DecoderPcmSampleLayout>, pub codec_delay_samples: Option<u32>, pub priming_samples: Option<u32>, pub trailing_padding_samples: Option<u32>, pub seek_preroll_samples: Option<u32>, pub prefer_hardware: bool, pub required_decoder_implementation_name: Option<String>, pub require_cpu_output: bool, pub native_device_context: Option<DecoderNativeDeviceContext>, pub color: Option<NativeFrameColorMetadata>, pub hdr: Option<NativeFrameHdrMetadata>,
}
Configuration used to open a decoder session.

Fields

codec: Stringmedia_kind: DecoderMediaKindextradata: Vec<u8>bitstream_format: Option<DecoderBitstreamFormat>width: Option<u32>height: Option<u32>coded_width: Option<u32>coded_height: Option<u32>reorder_depth: Option<u32>sample_rate: Option<u32>channels: Option<u16>channel_layout: Option<String>target_pcm_format: Option<DecoderFrameFormat>target_pcm_sample_layout: Option<DecoderPcmSampleLayout>codec_delay_samples: Option<u32>priming_samples: Option<u32>trailing_padding_samples: Option<u32>seek_preroll_samples: Option<u32>prefer_hardware: boolrequired_decoder_implementation_name: Option<String>

Platform decoder implementation selected by a trusted host capability probe.

require_cpu_output: boolnative_device_context: Option<DecoderNativeDeviceContext>color: Option<NativeFrameColorMetadata>hdr: Option<NativeFrameHdrMetadata>

Implementations

Source

impl DecoderSessionConfig

pub fn audio_from_source_normalizer_track( track: &SourceNormalizerPacketTrackInfo, target_pcm_format: DecoderFrameFormat, target_pcm_sample_layout: DecoderPcmSampleLayout, ) -> Result<Self, DecoderError>

Builds an audio decoder session config from a SourceNormalizer audio track.

pub fn apple_native_audio_from_source_normalizer_track( track: &SourceNormalizerPacketTrackInfo, ) -> Result<Self, DecoderError>

Builds the default Apple PCM output preference for native audio.