FrameProcessorSessionRequirements

Struct FrameProcessorSessionRequirements 

pub struct FrameProcessorSessionRequirements {
    pub input_metadata: NativeFrameMetadata,
    pub output_handle_kind: Option<NativeHandleKind>,
    pub output_pipeline_profile: Option<NativeFramePipelineProfile>,
    pub require_video_frames: bool,
    pub require_native_first: bool,
    pub require_explicit_native_input: bool,
    pub require_flush: bool,
    pub reject_dimension_changes: bool,
    pub require_color_metadata_preservation: bool,
    pub require_hdr_metadata_preservation: bool,
    pub max_in_flight_frames: Option<u32>,
}
Capability requirements used when opening one frame processor session.

Fields

input_metadata: NativeFrameMetadataoutput_handle_kind: Option<NativeHandleKind>output_pipeline_profile: Option<NativeFramePipelineProfile>require_video_frames: boolrequire_native_first: boolrequire_explicit_native_input: boolrequire_flush: boolreject_dimension_changes: boolrequire_color_metadata_preservation: boolrequire_hdr_metadata_preservation: boolmax_in_flight_frames: Option<u32>

Implementations

Source

impl FrameProcessorSessionRequirements

pub fn native_video(input_metadata: NativeFrameMetadata) -> Self

Builds native video requirements for a decoded frame processor chain.

pub fn missing_capabilities( &self, capabilities: &FrameProcessorCapabilities, ) -> Vec<String>

Returns missing capability names for this requirement.