PluginArtifactDescriptor

Struct PluginArtifactDescriptor 

pub struct PluginArtifactDescriptor {
Show 17 fields pub schema_version: u32, pub plugin_id: String, pub version: String, pub publisher: String, pub transport: PluginArtifactTransport, pub target: String, pub format: PluginArtifactFormat, pub architecture: String, pub abi_major: u16, pub abi_minor_min: u16, pub abi_minor_max: u16, pub capabilities: Vec<PluginArtifactCapability>, pub requires: Vec<PluginRequirement>, pub provides: Vec<PluginProvision>, pub runtime_dependencies: Vec<PluginRuntimeDependency>, pub resource_policy: PluginResourcePolicy, pub migration_version: String,
}
Artifact metadata that can be inspected without opening the artifact.

Fields

schema_version: u32plugin_id: Stringversion: Stringpublisher: Stringtransport: PluginArtifactTransporttarget: Stringformat: PluginArtifactFormatarchitecture: Stringabi_major: u16abi_minor_min: u16abi_minor_max: u16capabilities: Vec<PluginArtifactCapability>requires: Vec<PluginRequirement>provides: Vec<PluginProvision>runtime_dependencies: Vec<PluginRuntimeDependency>resource_policy: PluginResourcePolicymigration_version: String

Implementations

Source

impl PluginArtifactDescriptor

pub fn from_parts( plugin_id: impl Into<String>, version: impl Into<String>, publisher: impl Into<String>, transport: PluginArtifactTransport, target: impl Into<String>, format: PluginArtifactFormat, architecture: impl Into<String>, abi_major: u16, abi_minor_min: u16, abi_minor_max: u16, capabilities: Vec<PluginArtifactCapability>, ) -> Result<Self, PluginCatalogError>

Constructs and validates a descriptor from the stable artifact fields. Optional dependency/resource declarations can be added before calling Self::canonicalize.

pub fn from_json(bytes: &[u8]) -> Result<Self, PluginCatalogError>

Decodes and validates one descriptor from canonical JSON input.

pub fn to_json(&self) -> Result<Vec<u8>, PluginCatalogError>

Encodes the validated descriptor in deterministic JSON form.

pub fn validate(&self) -> Result<(), PluginCatalogError>

Validates the descriptor without loading or probing an artifact.

pub fn canonicalize( &self, ) -> Result<CanonicalPluginArtifactDescriptor, PluginCatalogError>

Produces stable JSON and a SHA-256 identity for catalog metadata.

pub fn fingerprint(&self) -> Result<String, PluginCatalogError>

pub fn plugin_reference( &self, capability_instance_id: Option<String>, ) -> Result<PluginReference, PluginCatalogError>