pub struct PluginPlan { /* private fields */ }Expand description
Canonical metadata-only result that can be inspected before runtime startup.
Implementations
Sourceimpl PluginPlan
impl PluginPlan
pub const fn schema_version(&self) -> u32
pub fn catalog_fingerprint(&self) -> &str
pub fn catalog(&self) -> &[PluginCatalogRecord]
pub fn policy(&self) -> &PluginPlanPolicy
pub fn requirements(&self) -> &[PluginRequirement]
pub fn providers(&self) -> &[PluginPlanProvider]
Sourcepub fn artifacts(&self) -> &[PluginCatalogRecord]
pub fn artifacts(&self) -> &[PluginCatalogRecord]
Returns selected artifacts in dependency-first execution order.
pub fn fingerprint(&self) -> &str
Sourcepub fn to_json(&self) -> Result<Vec<u8>, PluginPlanError>
pub fn to_json(&self) -> Result<Vec<u8>, PluginPlanError>
Encodes the complete plan envelope in canonical JSON field and array order.
Sourcepub fn from_json(bytes: &[u8]) -> Result<Self, PluginPlanError>
pub fn from_json(bytes: &[u8]) -> Result<Self, PluginPlanError>
Decodes a plan and rejects stale, tampered, or noncanonical projections.