FrameProcessorCapabilities

Struct FrameProcessorCapabilities 

pub struct FrameProcessorCapabilities {
Show 13 fields pub accepted_input_handle_kinds: Vec<NativeHandleKind>, pub output_handle_kinds: Vec<NativeHandleKind>, pub accepted_input_pipeline_profiles: Vec<NativeFramePipelineProfile>, pub output_pipeline_profiles: Vec<NativeFramePipelineProfile>, pub supports_video_frames: bool, pub supports_in_place_passthrough: bool, pub preserves_dimensions: bool, pub may_change_dimensions: bool, pub preserves_color_metadata: bool, pub preserves_hdr_metadata: bool, pub supports_flush: bool, pub max_sessions: Option<u32>, pub max_in_flight_frames: Option<u32>,
}
Native-frame capabilities advertised by a frame processor plugin.

Fields

accepted_input_handle_kinds: Vec<NativeHandleKind>output_handle_kinds: Vec<NativeHandleKind>accepted_input_pipeline_profiles: Vec<NativeFramePipelineProfile>output_pipeline_profiles: Vec<NativeFramePipelineProfile>supports_video_frames: boolsupports_in_place_passthrough: boolpreserves_dimensions: boolmay_change_dimensions: boolpreserves_color_metadata: boolpreserves_hdr_metadata: boolsupports_flush: boolmax_sessions: Option<u32>max_in_flight_frames: Option<u32>

Implementations

Source

impl FrameProcessorCapabilities

pub fn supports_input_handle_kind(&self, handle_kind: &NativeHandleKind) -> bool

Returns whether the processor accepts an input native handle kind.

pub fn supports_input_pipeline_profile( &self, profile: &NativeFramePipelineProfile, ) -> bool

Returns whether the processor accepts a native-frame pipeline profile.

pub fn supports_input_metadata(&self, metadata: &NativeFrameMetadata) -> bool

Returns whether both handle kind and pipeline profile match the metadata.

pub fn supports_output_handle_kind( &self, handle_kind: &NativeHandleKind, ) -> bool

Returns whether the processor can produce an output native handle kind.

pub fn supports_output_pipeline_profile( &self, profile: &NativeFramePipelineProfile, ) -> bool

Returns whether the processor can produce an output pipeline profile.